 /*
 * Copyright (c) 2021-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under the terms of the
 * OpenIB.org BSD license included below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#include "uphy_common.h"

namespace UPHY
{
    const char * to_c_str(register_unit_flags_t value)
    {
        switch( value )
        {
            case RegisterUnitFlags_None  : return "None";
            case RegisterUnitFlags_RX    : return "RX";
            case RegisterUnitFlags_TX    : return "TX";
            case RegisterUnitFlags_CLM   : return "CLM";

            default:
                return "UNKNOWN";
        }
    }

    const char * to_c_str(register_access_flags_t value)
    {
        switch( value )
        {
            case RegisterAccessFlags_None        : return "None";
            case RegisterAccessFlags_ReadOnly    : return "RO";
            case RegisterAccessFlags_WriteOnly   : return "WO";
            case RegisterAccessFlags_ReadWrite   : return "RW";
            case RegisterAccessFlags_Proxy       : return "PROXY";
            case RegisterAccessFlags_All         : return "ALL";

            default:
                return "UNKNOWN";
        }
    }

    const char * to_c_str(register_secure_t value)
    {
        switch( value )
        {
            case RegisterSecureType_None    : return "None";

            default:
                return "UNKNOWN";
        }
    }

    const char * to_c_str(register_field_t value)
    {
        switch( value )
        {
            case RegisterSecureType_None        : return "None";
            case RegisterFieldType_Signed       : return "Signed";
            case RegisterFieldType_UnSigned     : return "UnSigned";
            case RegisterFieldType_Enum         : return "Enum";

            default:
                return "UNKNOWN";
        }
    }

    const char * to_c_str(dataset_type_t value)
    {
        switch( value )
        {
            case DataSetType_None    : return "None";
            case DataSetType_DLN     : return "DLN";
            case DataSetType_CLN     : return "CLN";

            default:
                return "UNKNOWN";
        }
    }
}

