/*                  - Mellanox Confidential and Proprietary -
 *
 *  Copyright (C) 2010-2020, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
 *  Copyright (c) 2022-2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 *  Except as specifically permitted herein, no portion of the information,
 *  including but not limited to object code and source code, may be reproduced,
 *  modified, distributed, republished or otherwise exploited in any form or by
 *  any means for any purpose without the prior written permission of Mellanox
 *  Technologies Ltd. Use of software subject to the terms and conditions
 *  detailed in the file "COPYING".
 *
 */


#ifndef SMP_AR_QUERY_TYPES_H_
#define SMP_AR_QUERY_TYPES_H_


#include <stdlib.h>


/****************************************************/
/* defines - options */
#define TOOL_NAME "smparquery"
#define TOOL_DESC "TODO - tool description"

#define OPTION_CA "Ca"
#define OPTION_CA_SHORT 'C'
#define OPTION_CA_ARG_DESC "<ca>"
#define OPTION_CA_DESC "Ca name to use"

#define OPTION_PORT "Port"
#define OPTION_PORT_SHORT 'P'
#define OPTION_PORT_ARG_DESC "<port>"
#define OPTION_PORT_DESC "Ca port number to use"

#define OPTION_DR "Direct"
#define OPTION_DR_SHORT 'D'
#define OPTION_DR_ARG_DESC ""
#define OPTION_DR_DESC "use Direct address argument"

#define OPTION_LID "Lid"
#define OPTION_LID_SHORT 'L'
#define OPTION_LID_ARG_DESC ""
#define OPTION_LID_DESC "use LID address argument"

#define OPTION_HELP "help"
#define OPTION_HELP_SHORT 'h'
#define OPTION_HELP_ARG_DESC ""
#define OPTION_HELP_DESC "help message"

#define OPTION_VERSION "version"
#define OPTION_VERSION_SHORT 'V'
#define OPTION_VERSION_ARG_DESC ""
#define OPTION_VERSION_DESC "show version"

#define OPTION_DEBUG "debug"
#define OPTION_DEBUG_SHORT 'd'
#define OPTION_DEBUG_ARG_DESC ""
#define OPTION_DEBUG_DESC "Print debug logs"

#define MAX_VALID_CONTROL_MAP_VALUE    (PORT_MASK_ENABLE | LFT_TOP_ENABLE)

#define DEFAULT_LOG_SIZE        50                  /* 5 MB */

/* defines - log */
#define WARN_PRINT(fmt, ...)    printf("-W- " fmt, ## __VA_ARGS__)
#define INFO_PRINT(fmt, ...)    printf("-I- " fmt, ## __VA_ARGS__)
#define ERR_PRINT(fmt, ...)     printf("-E- " fmt, ## __VA_ARGS__)


/****************************************************/
/* new types */
typedef int (*op_fn_t)(Ibis *p_ibis,
        u_int16_t lid, direct_route_t *p_direct_route,
        string optional_args);

typedef struct match_rec {
    const char *name, *alias;
    op_fn_t fn;
    u_int64_t params;
} match_rec_t;

/*
 * Enumeration of smparquery options parameters,
 * each bit represent a different option parameter.
 * Values increase by power of 2.
*/
typedef enum options_params {
    NO_PARAMS         = 0,
    PARAM_PLFT        = (1u << 0),
    PARAM_GROUP_TBL   = (1u << 1),
    PARAM_BLOCK_NUM   = (1u << 2),
    PARAM_CONTROL_MAP = (1u << 3)
} options_params_t;

typedef enum control_map_bits {
    NO_BIT_SET         = 0,
    PORT_MASK_ENABLE   = (1u << 0),
    LFT_TOP_ENABLE     = (1u << 1)
} control_map_bits_t;


#endif  /* SMP_AR_QUERY_TYPES_H_ */
